@@ -17,7 +17,22 @@ from openpyxl.utils.exceptions import InvalidFileException
 from xlrd import XLRDError
 
 
+def clean_directory(path):
+    """清空文件夹"""
+    if not os.path.exists(path):
+        return
+    for i in os.listdir(path):
+        path_file = os.path.join(path, i)
+        if os.path.isfile(path_file):
+            os.remove(path_file)
+        else:
+            for f in os.listdir(path_file):
+                path_file2 = os.path.join(path_file, f)
+            if os.path.isfile(path_file2):
+                os.remove(path_file2)
+
 def create_excel_xlsx(path, sheet_name):
+    """创建excel"""
     workbook = op.Workbook()
     sheet = workbook.active
     sheet.title = sheet_name
