@@ -1,12 +1,15 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # @XZGUtil    : 2021-01-05 16:10
-# @Site    : 
+# @Site    :
 # @File    : messageUtil.py
 # @Software: PyCharm
 """
 消息类
 """
+import json
+
+import requests
 from postcard import Smtp
 
 
@@ -32,4 +35,19 @@ def init_emal(title,message,send_user,user, pwd, smtp_addr='smtp.mxhichina.com',
         """
         ret = smtp.send_mail(subject=f"{title}", content=f"{message}", receiver=send_user)
         print(ret)
-    send_emil()
\ No newline at end of file
+    send_emil()
+
+def send_ding_message(url, message, at:list=None):
+    """
+    发送钉钉消息
+    :param message:
+    :param url:
+    :param at: ['15210327885']
+    :return:
+    """
+    try:
+        data = {"msgtype": "text", "text": {"content": '{}'.format(message)}, "at": {"atMobiles": at, "isAtAll": False}}
+        header = {'Content-Type': 'application/json'}
+        requests.post(url, headers=header, data=json.dumps(data), timeout=5)
+    except Exception as e:
+        print(e)
